use base qw(Test::Class);
use Test::More;
use strict;

use DE_EPAGES::Core::API::Error qw ( GetError ExistsError );
use DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder;

use constant LENGTH => 12;

sub checkConstructor : Test(no_plan) {
    my $builder =
      DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder->new(
        length => LENGTH );
    isa_ok(
        $builder,
        'DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder',
        'built BaseFieldBuilder'
    );
}

sub validateBuilder : Test(no_plan) {
    eval {
        DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder->new();
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'UNDEF_VALUE', 'BaseFieldBuilder param validation' )
          or diag( $Error->longMessage );
    }
}

sub checkEmtpyValueBuilder : Test(no_plan) {
    my $builder =
      DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder->new(
        length => LENGTH );
    is( $builder->build(), '            ', 'check empty value builder' );
}

sub checkBuilder : Test(no_plan) {
    my $value   = 'aValue';
    my $builder = DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder->new(
        length => LENGTH,
        value  => $value
    );
    is( $builder->build(), 'aValue      ', 'check empty value builder' );
}

sub longValue : Test(no_plan) {
    my $value   = 'longer then 12';
    my $builder = DE_EPAGES::SDA::API::File::Record::BaseFieldBuilder->new(
        length => LENGTH,
        value  => $value
    );
    is( $builder->build(), 'longer then ', 'check value longer than length' );
}

Test::Class->runtests;
