use base qw(Test::Class);
use Test::More;
use strict;
use DE_EPAGES::SDA::API::File::Record::ComposedBuilder;
use DE_EPAGES::Core::API::Script qw( RunScript );
use Test::MockObject;

use constant TEXT_1 => 'build1 text';
use constant TEXT_2 => 'build2 text';

sub before : Test(setup) {
    my $self = shift;
    $self->{builder1} = Test::MockObject->new();
    $self->{builder1}->mock( 'build', sub { TEXT_1 } );

    $self->{builder2} = Test::MockObject->new();
    $self->{builder2}->mock( 'build', sub { TEXT_2 } );
}

sub twoBuilders : Test(no_plan) {
    my $self = shift;
    my @builders = ( $self->{'builder1'}, $self->{'builder2'} );
    my $composedBuilder =
      DE_EPAGES::SDA::API::File::Record::ComposedBuilder->new(
        'list' => \@builders );
    ok( $composedBuilder->build() eq TEXT_1 . TEXT_2, 'two builders OK' );
}

sub noBuilders : Test(no_plan) {
    my $self = shift;
    my $composedBuilder =
      DE_EPAGES::SDA::API::File::Record::ComposedBuilder->new();
    ok( $composedBuilder->build() eq '', 'no builders OK' );
}

RunScript( Sub => sub { Test::Class->runtests; } );
