use DE_EPAGES::Core::API::Script qw ( RunScript );
use Test::More;

use DE_EPAGES::SDA::API::File::Filename::DataFilenameBuilder;
use DE_EPAGES::SDA::API::File::Filename::NotifFilenameBuilder;

use DE_EPAGES::Core::API::Error qw ( GetError ExistsError );

use strict;

use constant DATE         => '20110427120000';
use constant ORDER_NUMBER => 1000;

use constant EXPECTED_FILENAME => DATE . '_' . ORDER_NUMBER;

my $date = DateTime->new(
    year      => 2011,
    month     => 4,
    day       => 27,
    hour      => 12,
    minute    => 0,
    second    => 0,
    time_zone => 'Europe/Berlin'
);

sub run_data_tests {

    eval {
        DE_EPAGES::SDA::API::File::Filename::DataFilenameBuilder->new(
            date => $date );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'UNDEF_VALUE', 'orderNr param validation' );
    }

    my $dataFilenameBuilder =
      DE_EPAGES::SDA::API::File::Filename::DataFilenameBuilder->new(
        orderNumber => ORDER_NUMBER,
        date        => $date
      );

    ok(
        defined $dataFilenameBuilder,
'DE_EPAGES::SDA::API::File::Filename::DataFilenameBuilder->new() returned something'
    );
    ok(
        $dataFilenameBuilder->isa(
            'DE_EPAGES::SDA::API::File::Filename::FilenameBuilder'),
        'DE_EPAGES::SDA::API::File::FilenameBuilder class returned'
    );
    is(
        $dataFilenameBuilder->build,
        EXPECTED_FILENAME . '.dat',
        'data filename is correct'
    );
}

sub run_notif_tests {

    eval {
        DE_EPAGES::SDA::API::File::Filename::NotifFilenameBuilder->new(
            date => $date );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'UNDEF_VALUE', 'orderNr param validation' );
    }

    my $notifFilenameBuiler =
      DE_EPAGES::SDA::API::File::Filename::NotifFilenameBuilder->new(
        orderNumber => ORDER_NUMBER,
        date        => $date
      );

    ok(
        defined $notifFilenameBuiler,
'DE_EPAGES::SDA::API::File::Filename::NotifFilenameBuilder->new() returned something'
    );
    ok(
        $notifFilenameBuiler->isa(
            'DE_EPAGES::SDA::API::File::Filename::NotifFilenameBuilder'),
        'DE_EPAGES::SDA::API::File::Filename::FilenameBuilder class returned'
    );
    is(
        $notifFilenameBuiler->build,
        EXPECTED_FILENAME . '.dis',
        'notification filename is correct'
    );
}

sub Main {
    run_data_tests run_notif_tests;
    done_testing;
}

RunScript( Sub => \&Main );

1;
