use strict;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use Test::More;
use DE_EPAGES::Object::API::Factory qw (
  ExistsObjectByPath
  LoadObjectByPath
  LoadRootObject
);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw ( ImportObjects );
use DE_EPAGES::SDA::API::Config::MerchantCredentials;

my $ROOTPATH = '/Test';

sub Main {
    RunOnStore(
        'Store' => GetTestSite(),
        'Sub'   => sub {

            # initialization
            ok( Init(), 'initialization' );

            # tests
            my $aCredentials =
              DE_EPAGES::SDA::API::Config::MerchantCredentials
              ->getAllMerchantCredentials( 'Store', 1 );
            is(
                scalar(
                    grep {
                             $_->username eq 'TestUsername'
                          && $_->password eq 'TestPassword'
                      } @{$aCredentials}
                ),
                1,
                'Merchant credentials retrieved'
            );

            # cleanup
            ok( Cleanup(), 'cleanup' );
            done_testing();
        }
    );
}

sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

sub Init {
    return 1 if ExistsObjectByPath($ROOTPATH) && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild( 'Object', { Alias => 'Test' } );
    ImportObjects( 'import.xml', $ROOTPATH );
    return 1;
}

RunScript( Sub => \&Main );

1;
