use base qw(Test::Class);
use Test::More;
use strict;
use DE_EPAGES::Core::API::Error qw ( GetError ExistsError );
use DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder;

sub lengthDefaultsToZero : Test(no_plan) {
    eval {
        DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder->new(
            'value' => 12 );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'TOO_LONG_VALUE', 'lengthDefaultsToZero' )
          or diag( $Error->longMessage );
    }
}

sub checkEmtpyValueBuilder : Test(no_plan) {
    eval {
        DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder->new(
            length => 5 );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'UNDEF_VALUE', 'checkEmtpyValueBuilder' )
          or diag( $Error->longMessage );
    }

    eval {
        DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder->new();
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'UNDEF_VALUE', 'checked empty value error' )
          or diag( $Error->longMessage );
    }

}

sub checkBuilder : Test(no_plan) {

    my $builder = DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder->new(
        'length' => 5,
        'value'  => 123
    );
    is( $builder->build(), '00123', 'builder OK' );
}

sub valueTooLong : Test(no_plan) {
    eval {
        DE_EPAGES::SDA::API::File::Record::NumberFieldBuilder->new(
            'length' => 5,
            'value'  => 123456,
        );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'TOO_LONG_VALUE', 'validation ok' )
          or diag( $Error->longMessage );
    }
}

Test::Class->runtests;
