use base qw(Test::Class);
use DE_EPAGES::SDA::API::File::SDAFileBuilder;
use Test::More;
use DE_EPAGES::SDA::API::Object::ShippingLabelSDA qw ( STANDARD_SHIPPING );

use strict;

my $date = DateTime->new(
    year      => 2011,
    month     => 4,
    day       => 30,
    hour      => 10,
    minute    => 10,
    second    => 10,
    time_zone => 'Europe/Berlin'
);

my $order_number           = 'ord-1002';
my $customerIdCode1        = 'CLI000000009';
my $blanks2                = '                              ';
my $shipmentType3          = 'N';
my $activateCollection4    = 'N';
my $printConsignementNote5 = 'S';
my $shipRefNumber          = '123-ship-ref-number';

my $shipDate      = '20110501';
my $shipDateParam = DateTime->new(
    year  => 2011,
    month => 5,
    day   => 1
);
my $collectionMP     = 'P';
my $parcelsNumber    = 5;
my $productRefCode   = 'PR-5678';
my $recipientRefCode = 'CL-1234';

use constant CODE              => '12345678901234567890';
use constant CODE_BLANK        => '                    ';
use constant COMPANY           => 'My Company Ltd.';
use constant COMPANY_BLANK     => '                         ';
use constant CONTACT           => 'My Contact';
use constant CONTACT_BLANK     => '          ';
use constant STREET_TYPE_BLANK => '    ';
use constant STREET            => 'Via Margutta';
use constant STREET_BLANK      => '                  ';
use constant NUMBER            => '123';
use constant NUMBER_BLANK      => '  ';
use constant PHONE             => '555-555555';
use constant PHONE_BLANK       => '     ';
use constant POSTCODE          => '63123';
use constant POSTCODE_BLANK    => '    ';
use constant TOWN              => 'Domodossola';
use constant TOWN_BLANK        => '                   ';
use constant PROVINCE          => 'Do';
use constant PARCELS_NUMBER    => '005';
use constant WEIGHT            => '0001500';
use constant WIDTH             => '00000';
use constant HEIGHT            => '00000';
use constant DEPTH             => '00000';
use constant PRD_BLANKS        => '             ';
use constant REC_BLANKS        => '             ';
use constant CURRENCY          => 'EU';
use constant CASH_AMOUNT       => '000000.00';
use constant INSURED_AMOUNT    => '0' . CASH_AMOUNT;
use constant PAYMENT_TYPE      => '   ';
use constant NOTES             => '                              ';
use constant PARCEL_IDENTIF    => '123-ship-ref-number-5    ';
use constant BRANCH            => 'RM';
use constant CONTENTS          => 'contents blah blah...         ';
use constant SHIPMENT_BLANK    => '      ';
use constant CONTENT_TYPE      => 'P';
use constant SENDER_COUNTRY    => 'IT';
use constant RECIPIENT_COUNTRY => 'IT';
use constant SHIPMENT_VALUE    => INSURED_AMOUNT;
use constant CUSTOMENR_TYPE    => 'PCIM';
use constant SHIPMENT_CLASS    => '          ';
use constant EMAIL             => 'email@example.com';
use constant MOBILE_NUMBER     => '07341234567890';

my %filenameparams = (
    'date'        => $date,
    'orderNumber' => $order_number,
);

my %SenderAddress = (
    'code'     => CODE,
    'person_or_company_name'  => COMPANY,
    'contact'  => CONTACT,
    'street'   => STREET . ' ' . NUMBER,
    'phone'    => PHONE,
    'postcode' => POSTCODE,
    'town'     => TOWN,
    'province' => PROVINCE,
);

my %ReceiverAddress = (
    'code'     => CODE,
    'person_or_company_name'  => COMPANY,
    'contact'  => CONTACT,
    'street'   => STREET . ' ' . NUMBER,
    'phone'    => PHONE,
    'postcode' => POSTCODE,
    'town'     => TOWN,
    'province' => PROVINCE,
);

my %params = (
    'customerIdCode'        => $customerIdCode1,
    'shipmentRefNumber'     => $shipRefNumber,
    'shipmentDate'          => $shipDateParam,
    'senderAddress'         => \%SenderAddress,
    'receiverAddress'       => \%ReceiverAddress,
    'parcelsNumber'         => $parcelsNumber,
    'serviceCode'           => STANDARD_SHIPPING,
    'productRefCode'        => $productRefCode,
    'recipientRefCode'      => $recipientRefCode,
    'branch'                => BRANCH,
    'contents'              => 'contents blah blah...',
    'senderCountry'         => SENDER_COUNTRY,
    'recipientCountry'      => RECIPIENT_COUNTRY,
    'recipientEmail'        => EMAIL,
    'recipientMobileNumber' => MOBILE_NUMBER,
);

sub before : Test(setup) {
    my $self = shift;
    $self->{'builder'} =
      DE_EPAGES::SDA::API::File::SDAFileBuilder->new(%filenameparams);
    $self->{'builder'}->addRecord(%params);
}

sub checkConstructor : Test(no_plan) {
    my $self    = shift;
    my $builder = $self->{'builder'};
    isa_ok( $builder, 'DE_EPAGES::SDA::API::File::SDAFileBuilder' );
}

use constant RESULT =>
'CLI000000009                              NNS123-ship-ref-number      20110501P12345678901234567890My Company Ltd.'
  . '                         My Contact               Via Margutta                  123  555-555555     63123    Domodossola'
  . '                   Do                    My Company Ltd.                         My Contact               Via Margutta'
  . '                  123  555-555555     63123    Domodossola                   Do005                      '
  . STANDARD_SHIPPING
  . 'PR-5678'
  . '             CL-1234             EU000000.00                                 0000000.00                         RM'
  . 'contents blah blah...         PIT IT 0000000.00PCIM                               email@example.com'
  . "                                 07341234567890\n";

use constant FILENAME => '20110430101010_ord-1002';

sub build : Test(no_plan) {
    my $self    = shift;
    my $builder = $self->{'builder'};
    is( $builder->dataRecord(),   RESULT,            'build data record' );
    is( $builder->dataFilename(), FILENAME . '.dat', 'build data filename' );
    is( $builder->notificationRecord(), '', 'build notif record' );
    is(
        $builder->notificationFilename(),
        FILENAME . '.dis',
        'build notif filename'
    );
}

Test::Class->runtests;
