use base qw(Test::Class);
use Test::More;
use strict;
use DE_EPAGES::Core::API::Error qw ( GetError ExistsError );
use DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder;
use DE_EPAGES::SDA::API::Object::ShippingLabelSDA
  qw ( STANDARD_SHIPPING INTERNATIONAL_SHIPPING);

sub standardValue : Test(no_plan) {
    my $builder =
      DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder->new(
        'serviceCode' => STANDARD_SHIPPING );
    isa_ok( $builder,
        'DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder' );
    is( $builder->build(), STANDARD_SHIPPING, 'standard service' );
}

sub internationalValue : Test(no_plan) {
    my $builder =
      DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder->new(
        'serviceCode' => INTERNATIONAL_SHIPPING );
    isa_ok( $builder,
        'DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder' );
    is( $builder->build(), INTERNATIONAL_SHIPPING, 'international service' );
}

sub invalidValue : Test(no_plan) {
    my $value = 'Error';
    eval {
        DE_EPAGES::SDA::API::File::Record::ServiceCodeFieldBuilder->new(
            'serviceCode' => $value );
        fail('must throw an exception');
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        is( $Error->code, 'INVALID_SERVICE_CODE', 'SDA invalid service' )
          or diag( $Error->longMessage );
    }
}

Test::Class->runtests;
